Module serialize

Module serialize 

XML serialization helpers for YANG-generated types.

Converts YANG-typed Rust structs into NETCONF-compatible XML for use with edit_config() and deserializes XML responses back into typed structs.

Structs

Cursor
A Cursor wraps an in-memory buffer and provides it with a Seek implementation.
Writer
XML writer. Writes XML Events to a std::io::Write implementor.

Enums

XmlError
XML serialization/deserialization error.

Traits

FromNetconfXml
Trait for types that can be deserialized from NETCONF XML.
ToNetconfXml
Trait for types that can be serialized to NETCONF XML.
WriteXmlFields
Trait for types that can serialize their child fields into an XML writer.

Functions

finish_writer
Extract the XML string from a writer.
new_writer
Create a new XML writer.
write_element_with_fields
Write a named XML element whose content comes from a WriteXmlFields value.
write_end
Helper to write a closing element.
write_start_with_ns
Helper to write an XML element with a namespace attribute.
write_text_element
Helper to write an XML element with text content.