XML serialization helpers for YANG-generated types.
Converts YANG-typed Rust structs into NETCONF-compatible XML for
use with edit_config() and deserializes XML responses back into
typed structs.
Structs
- Cursor
- A
Cursorwraps an in-memory buffer and provides it with aSeekimplementation. - Writer
- XML writer. Writes XML
Events to astd::io::Writeimplementor.
Enums
- XmlError
- XML serialization/deserialization error.
Traits
- From
Netconf Xml - Trait for types that can be deserialized from NETCONF XML.
- ToNetconf
Xml - Trait for types that can be serialized to NETCONF XML.
- Write
XmlFields - Trait for types that can serialize their child fields into an XML writer.
Functions
- finish_
writer - Extract the XML string from a writer.
- new_
writer - Create a new XML writer.
- write_
element_ with_ fields - Write a named XML element whose content comes from a
WriteXmlFieldsvalue. - write_
end - Helper to write a closing element.
- write_
start_ with_ ns - Helper to write an XML element with a namespace attribute.
- write_
text_ element - Helper to write an XML element with text content.